#!/bin/sh
#
# (c) Copyright 2018, 2022 Basement Supercomputing
# Script to collect Limulus data
# 
# last update: Wed Jun 15 17:06:17 EDT 2022
# Assumes Limulus install with CentOS7 and OpenHPC or HDP Hadoop

#set -x

# Adjust for OHPC or HADOOP
OPTPATH=""
if [ -d /opt/ohpc ]; then
  OPTPATH="/opt/ohpc"
elif [ -d /opt/cluster ]; then
  OPTPATH="/opt/cluster"
fi
if [ "$OPTPATH" == "" ]; then
  echo "Cannot find valid /opt path, exiting."
  exit 1
fi
SCRIPTPATH=$OPTPATH/admin/etc
VERSION="2.0"

createfile()
{
# arguments, node, command, output file
echo "<html><body bgcolor=\"#FFFFFF\">" > $1/$3
echo "<pre>" >>$1/$3
if [ "$1" = "$HEADNODE" ]; then
   $2 >> $1/$3  2>&1
else
 ssh $1  $2 >> $1/$3  2>&1
fi
echo "</pre>" >>$1/$3
echo "</html></body>" >> $1/$3
}

createindexfile ()
{
# arguments node
LIST=`ls *.html`
echo "<html><body bgcolor=\"#FFFFFF\">" >index.html
echo "<H2>Machine: $1</H2>" >>index.html
echo "<H3>$DATE</H3>"  >>index.html
for I in $LIST
do
  J=`basename $I .html`
  echo "<a href=\"$I\">$J</a><br>"  >>index.html
done
echo "</html></body>" >> index.html
}

if [ ! $UID = "0" ] 
then 
	echo "Please run this script as root."
	exit 1
fi
HEADNAME=`hostname`
HEADNODE=`hostname -a`
# use dmidecode, strip off any messages before ID
MACHINEID=`dmidecode -s system-uuid|tail -n1`
NODELIST=`pdsh pwd|gawk -F: '{print $1}'|sort`
DATE=`date +%F`_`date +%R`
BASEDIR=/var/warewulf
echo -n "Collecting data for System: "
echo $HEADNAME-$MACHINEID
echo "Nodes:"
echo $NODELIST
# create scripts to gather data
cat <<EOF >$SCRIPTPATH/ifcfg-files.sh
FILES=\$(/bin/ls /etc/sysconfig/network-scripts/ifcfg-*)
for I in \$FILES; do
echo -n "<P><B>"
echo -n \$I
echo "</B>"
cat \$I
done
EOF
cat <<EOF >$SCRIPTPATH/hdparm-disk.sh 
LIST=\`/sbin/fdisk -l 2> /dev/null|grep bytes|grep dev\/sd |gawk '{print \$2}'|gawk -F: '{print \$1}'\`
for DRIVE in \$LIST
do
echo "<P><B>\$DRIVE</B>"
/sbin/hdparm -i \$DRIVE
done
EOF
cat <<EOF >$SCRIPTPATH/run-ethtool.sh
IF=\`ifconfig |grep mtu| gawk '{print \$1}'\`
for I in \$IF
do
echo "<P><B>INTERFACE \$I</B>"
I2=\${I:0:2}
if [ "\$I2" == "br" ]
then
  /usr/sbin/brctl show \$I
else
  /sbin/ethtool \$I
  /sbin/ethtool -i \$I
fi
done
EOF

mkdir -p $BASEDIR/$HEADNAME-$MACHINEID/$DATE
cd  $BASEDIR/$HEADNAME-$MACHINEID/$DATE
# headnode specific 
mkdir -p $HEADNODE
createfile $HEADNODE  "echo $DATE" log-date.html
  if [ -x /usr/bin/wwsh ]; then
    createfile $HEADNODE 'wwsh vnfs list' warewulf-vnfs.html
    createfile $HEADNODE 'wwsh file print'  warewulf-file.html
    createfile $HEADNODE 'wwsh bootstrap list'  warewulf-bootstrap.html
    createfile $HEADNODE 'wwsh provision print'  warewulf-provision.html
    createfile $HEADNODE "tree $OPTPATH"  opt-tree.html
    createfile $HEADNODE  'cat /etc/warewulf/.Limulus/Limulus-startup.sh'  Limulus-systemd-startup.html
    createfile $HEADNODE  'cat /etc/warewulf/.Limulus/Limulus-node-startup.sh'  Limulus-NODE-systemd-startup.html

  else
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"' warewulf-vnfs.html
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"'  warewulf-file.html
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"'  warewulf-bootstrap.html
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"'  warewulf-provision.html
    createfile $HEADNODE "tree $OPTPATH"  opt-tree.html
    createfile $HEADNODE 'cat /etc/warewulf/.Limulus/Limulus-startup.sh'  Limulus-systemd-startup.html
    createfile $HEADNODE  'cat /etc/warewulf/.Limulus/Limulus-node-startup.sh' Limulus-NODE-systemd-startup.html
  fi
cd $HEADNODE
# collect import directories
echo "Collecting $OPTPATH/admin/etc /etc /root directories"
tar czf opt-ohpc-admin-etc.root.etc.tgz $OPTPATH/admin/etc  /etc
cd ..

FULLLIST="$HEADNODE $NODELIST"
for NAME in $FULLLIST
do
  mkdir -p $NAME
  echo -n "Collecting data from: $NAME "
  echo -n "."
  createfile $NAME 'rpm -qa' rpm-qa.html
  echo -n "."
  createfile $NAME  /usr/sbin/dmidecode  dmidecode.html
  echo -n "."
  createfile $NAME  '/bin/uname -a'  uname.html
  echo -n "."
  createfile $NAME  '/usr/bin/lscpu' cpuinfo.html
  echo -n "."
  createfile $NAME  lspci lspci.html
  echo -n "."
  createfile $NAME "sh $SCRIPTPATH/hdparm-disk.sh" hdparm.html
  echo -n "."
  createfile $NAME 'cat /proc/partitions' partitions.html
  echo -n "."
  createfile $NAME '/bin/df -hlT'  df-hlT.html
  echo -n "."
  createfile $NAME  '/sbin/fdisk -l ' fdisk.html
  echo -n "."
  createfile $NAME  'cat /etc/fstab ' fstab.html
  echo -n "."
  createfile $NAME  'ls -l /dev/disk/by-id ' dev-disk-byid.html
  echo -n "."
  createfile $NAME  'lsblk ' blockinfo.html
  echo -n "."
  createfile $NAME  'module avail'  modules-avail.html
  echo -n "."
  createfile $NAME  '/sbin/lsmod '  lsmod.html
  echo -n "."
  createfile $NAME  '/bin/dmesg '  dmesg.html
  echo -n "."
  createfile $NAME  "sh $SCRIPTPATH/ifcfg-files.sh" ifcfg-files.html
  echo -n "."
  createfile $NAME  '/sbin/ifconfig '  ifconfig.html
  echo -n "."
  createfile $NAME  "sh $SCRIPTPATH/run-ethtool.sh"  ethtool.html
  echo -n "."
  createfile $NAME  'netstat -rn'  netstat-rn.html
  echo -n "."
  createfile $NAME  'cat /etc/sysconfig/network'  etc-sysconfig-network.html
  echo -n "."
  createfile $NAME  '/usr/bin/free '  free.html
  echo -n "."
  createfile $NAME  'cat /etc/hosts'  etc-hosts.html
  echo -n "."
  createfile $NAME  ' cat /etc/ld.so.conf'  etc-ld.so.conf.html
  echo -n "."
  createfile $NAME  ' ulimit -a'  ulimit-a.html
  echo -n "."
  createfile $NAME  ' ls /etc/ld.so.conf.d'  etc-ld.so.conf.d.html
  echo ""  
  cd $NAME 
  createindexfile $NAME
  cd ..
done
# create master machine index file
echo "<html><body bgcolor=\"#FFFFFF\">" >index.html
echo "<H2>Machine ID: $MACHINEID</H2>" >>index.html
echo "<H3>Run Date: $DATE</H3>"  >>index.html
echo "<H3>Gather.sh Version: $VERSION</H3>"  >>index.html
echo "<ul>"  >>index.html
for NAME in $FULLLIST
do
echo "<li>Machine: <a href=\"$NAME/index.html\">$NAME</a></li> "  >>index.html
done
echo "</ul></body></html>"  >>index.html
# create master date index file
# This will allow multiple runs to be stored in the same tree
cd ..
DATELIST=`ls -d *-*-*_*|sort -r`
echo "<html><body bgcolor=\"#FFFFFF\">" >index.html
echo "<H2>Machine ID: $MACHINEID</H2>" >>index.html
echo "<H3>Most Recent Run Date: $DATE</H3>"  >>index.html
echo "<H3>Gather.sh Version: $VERSION</H3>"  >>index.html
echo "<ul>"  >>index.html
for NAME in $DATELIST
do
echo "<li>Run Date: <a href=\"$NAME/index.html\">$NAME</a></li> "  >>index.html
done
echo "</ul></body></html>"  >>index.html

#/bin/rm /opt/etc/hdparm-disk.sh 
cd $BASEDIR
tar czf $HEADNAME-$MACHINEID.tgz $HEADNAME-$MACHINEID/ 
echo "Please send a copy of:"
echo "   $BASEDIR/$HEADNAME-$MACHINEID.tgz  "
echo "to lregister@basement-supercomputing.com"
echo ""
echo "Results are viewable as an HTML file."
echo "Use 'links2 /var/warewulf/$HEADNAME-$MACHINEID/index.html' to view"
echo "Finished"
exit
