#!/bin/bash
KERNEL="5.8.5-1.el7.elrepo.x86_64"
NODES="n0 n1 n2"
VNFS="co7_base"
ETH="eth0"
LIMULUS_PATH="/etc/warewulf/.Limulus"
SLEEPWAIT=120
SLEEPSHORT=5
RELAYSTART=2
IPSTART=10
GATEWAY=10.0.0.1
printf "Limulus HPC Node Configuration
Wed May 18 10:55:38 EDT 2022
This program will automatically register the worker nodes.
It needs to be run successfully one time and there is no need to
run it again if the nodes are booting and operating correctly.
Enter 'y' to continue, all other keys quit. "
read ANS
if test "$ANS" != "y" ; then
  exit
fi
echo "Reset and turn all nodes off"
# reset and turn everything off
relayset init  >& /dev/null
relayset 1 off; relayset 2 off; relayset 3 off; relayset 4 off
sleep $SLEEPSHORT
# making sure there are no nodes provisioned
echo "Deleting all node provisions"
wwsh -y node delete n[0-2] 
wwsh dhcp update
# start registration loop
echo "Ignore 'unparseable dotted notation' ERROR"
echo "Ignore 'Auto-detected' WARNING" 
for N in $NODES
do
  echo "Registering $N"
wwnodescan --netdev=$ETH --bootstrap=$KERNEL --vnfs=$VNFS --ipaddr=10.0.0.$IPSTART --netmask=255.255.255.0 $N &
  relayset $RELAYSTART on
  sleep $SLEEPWAIT
  /bin/ping -q -c 1 $N >& /dev/null
  if [ "$?" -eq 0 ];
    then
        echo "$N is responding"
    else
        echo "$N is not responding, exiting, check $N screen, re-run script"
#        relayset $RELAYSTART off
        wwsh -y node delete n[0-2]
        /bin/rm -r /root/.ssh/known_hosts >& /dev/null
        exit 1
  fi
  let RELAYSTART=$RELAYSTART+1
  let IPSTART=$IPSTART+1
done
echo "Adding files to nodes"
wwsh -y provision set n[0-2] --files passwd,group,gmond.conf,authorized_keys,resolv.conf,idmapd.conf,report-ganglia-temp,Limulus-node-startup.sh,slurm.conf,munge.key

echo "Adding gateway to nodes"
wwsh -y node set n[0-2] -G $GATEWAY 
echo "Restarting nodes"
relayset 2 off; relayset 3 off; relayset 4 off
sleep  $SLEEPSHORT
relayset 2 on
sleep  $SLEEPSHORT
relayset 3 on
sleep  $SLEEPSHORT
relayset 4 on
sleep $SLEEPWAIT
# Do some post install clean-up
echo "Checking nodes"
# source the pdsh.sh file to the WCOL path
. /etc/profile.d/pdsh.sh 
# update WCOL path
/etc/warewulf/.Limulus/checknodes.sh
pdsh uptime
echo "# Generated by register-nodes.sh (used by Slurm WOL scripts)" >$LIMULUS_PATH/node-macs
for N in $NODES
do
  MAC=$(ssh $N ifconfig $ETH |grep ether|gawk '{print $2}')
  echo $N $MAC >> $LIMULUS_PATH/node-macs
done
echo "Node Registration Finished"
/etc/warewulf/.Limulus/gather.sh
echo "LIMULUS SYSTEM BUILD COMPLETE"
# NEED TO UPDATE run-npb-with-temps.sh (Wed Jun 15 17:06:17 EDT 2022)
# printf "Would you like to run the test suite?
# The suite runs the NAS parallel benchmarks
# and takes approximately 60 minutes.
# Enter 'y' to continue, all other keys quit. "
# read ANS
# if test "$ANS" != "y" ; then
#   exit
# fi
# echo "A user called 'tester' will be created."
# echo "Waiting 5 minutes for 'tester' credentials to propagate."
# sleep 300
# /etc/warewulf/.Limulus/post-install/hpc/run-npb-with-temps.sh
