#!/bin/bash
# Used by build script to test system
# (c) Copyright 2015 Basement Supercomputing

useradd tester

# create the run-nas-parallel-bench.sh
cat << EOF >/home/tester/run-nas-parallel-bench.sh
#!/bin/bash
# (c) Copyright 2015 Basement Supercomputing
# version 1.0 02-22-15
echo ""
echo "Limulus Baseline Tests for NAS Parallel Benchmarks"
DATE=\`date +%D\`
TIME=\`date +%T\`
echo "Start:  \$DATE \$TIME"
module load sge6
tar xvzf /opt/bps/src/npb.tar.gz >/dev/null
cd npb
echo ""
echo "RUNNING NAS SUITE FROM COMMAND LINE"
 ./run_suite -c gnu4 -n 16 -t C -m mpich2
# dump open-mx errors to /dev/null
 ./run_suite -c gnu4 -n 16 -t C -m ompi 2>/dev/null

echo ""
echo "RUNNING NAS SUITE THROUGH SGE"
 ./run_suite -c gnu4 -n 16 -t C -m mpich2 -s
echo -n  "Waiting. Queue not empty "
while [ \`qstat |grep "npb"|wc -l\` -gt 0 ]
do
  echo -n "." 
sleep  15
done
echo
 ./run_suite -c gnu4 -n 16 -t C -m ompi -s
echo -n  "Waiting. Queue not empty "
while [ \`qstat |grep "npb"|wc -l\` -gt 0 ]
do
  echo -n "." 
sleep  15
done
echo 
echo ""
echo "RESULTS FOR NPB RUNS"
./get-results results
DATE=\`date +%D\`
TIME=\`date +%T\`
echo "End:  \$DATE \$TIME"
exit
EOF

# create the temps-continuous.sh script
cat << EOF >/home/tester/temps-continuous.sh
#!/bin/bash
# (c) Copyright 2015 Basement Supercomputing
VERSION="1.0 05-31-14"
convertsecs() {
 ((h=\${1}/3600))
 ((m=(\${1}%3600)/60))
 ((s=\${1}%60))
 printf "%02d:%02d:%02d" \$h \$m \$s
}

if  [ "\$1" == "" ]; then
echo "provide output file name"
  exit 1
fi
if [ ! -f /usr/bin/whatsup ]; then
    echo "Whatsup package is required" >&2
    exit 1
fi
DATE=\`date +%D\`
TIME=\`date +%T\`
echo "Version: \$VERSION"  | tee -a \$1
echo "Start:  \$DATE \$TIME" | tee -a \$1
STARTTIME=\`date +%s\`
echo " "|tee -a \$1
while [ 1 ]
do
 RANGE=\`sensors|grep Physical|gawk -F\( '{print \$2}'|sed 's/)//g'|sed 's/ //g'\`
 TIME=\`date +%T\`
 CURTIME=\`date +%s\`
 let ETIME=\$CURTIME-\$STARTTIME
 echo -n "Node  CPU     Temp " |tee -a \$1
 echo -n "(\$RANGE) Run Time:" |tee -a \$1
 convertsecs \$ETIME |tee -a \$1
 echo "" |tee -a \$1
 UPNODES=\`/usr/bin/whatsup -u -s -m pingd\`
 NODES="\$UPNODES headnode"
 for N in \$NODES
 do
   TEMP=\`ssh \$N sensors|grep Physical|gawk '{print \$4}'\`
   LOAD=\`ssh \$N top -b -n2|grep Cpu|tail -n1|gawk '{print \$2}'|sed 's/us\,//g'\`
   if [ "\$N" == "headnode" ] ; then
     echo " hn:  \$LOAD:  \$TEMP" | tee -a \$1
   else
     echo " \$N:  \$LOAD:  \$TEMP" | tee -a \$1
   fi
 done
 sleep 20
done;
EOF
# Main tasks start here
chown tester:tester /home/tester/run-nas-parallel-bench.sh
DATETAG=`date +%F_%H-%M`
sh /home/tester/temps-continuous.sh  npb-temps.$DATETAG >/dev/null &
TEMPSPID=$!
su -c 'sh /home/tester/run-nas-parallel-bench.sh' - tester |tee npb-test.$DATETAG
/bin/kill $TEMPSPID 
wait $TEMPSPID 2>/dev/null
DATE=`date +%D`
TIME=`date +%T`
echo ""
echo "">>npb-temps.$DATETAG
echo "End:  $DATE $TIME">>npb-temps.$DATETAG
echo "FINISHED These results can be found in npb-test.$DATETAG"
echo "A temperature profile can be found in npb-temps.$DATETAG"
echo ""

