#!/bin/bash
# Limulus Slurm Resume 
# Copyright (c) Limulus Computing, Basement Supercomputing 2020
# TRIES is the number of times to try resume (power-on) a host (or host list)
# if node-poweron returns quickly because it could not get the lock 
# (i.e. another node is starting/stopping). 
# Note: if node-poweron gets the lock, it does not return until node is up
# If it does not get a lock (another node starting or stopping) then it waits
# for a randmom number of seconds between 20 and 180.
# 
# test for needed utilities
if [ ! -f /usr/sbin/node-poweron ]; then
  logger "Resume ERROR: Missing /usr/sbin/node-poweron. Exiting"
  exit 1
fi
if [ ! -f /usr/sbin/node-poweroff ]; then
  logger "Resume ERROR: Missing /usr/sbin/node-poweroff. Exiting"
  exit 1
fi
if [ ! -f /etc/warewulf/.Limulus/slurm-node-up.sh ]; then
  logger "Resume ERROR: Missing /etc/warewulf/.Limulus/slurm-node-up.sh. Exiting"
  exit 1
fi

TRIES=10
logger "Slurm Resume ($0) for node(s) $1"
hosts=`scontrol show hostnames $1`
for host in $hosts
do
 # make sure node is off
 RESULT=`sudo /etc/warewulf/.Limulus/slurm-node-up.sh $host`
 if [ "$RESULT" == "YES" ]; then
   logger "Resume: Host still up: sudo node-poweroff -s $host"
   #echo -n " ----- In RESUME `date` NODE: $host -----" >> /tmp/slurmresume
   sudo /usr/sbin/node-poweroff  $host 
 fi
 COUNT=1
 SLEEPTIME=30
 while [ "$COUNT" -le "$TRIES" ];do
   #logger "ATTEMPT $COUNT: sudo node-poweron -s $host"
   #echo " ----- In RESUME `date` NODE: $host -----" >> /tmp/slurmresume
   sudo /usr/sbin/node-poweron  $host 
   RESULT=`sudo /etc/warewulf/.Limulus/slurm-node-up.sh $host`
   logger "Resume: $host is up? = $RESULT"
   if [ "$RESULT" == "NO" ]; then
     let COUNT=$COUNT+1
     SLEEPTIME=`shuf -i20-180 -n1`
     logger "Resume: $host start-up will retry in $SLEEPTIME seconds"
     sleep $SLEEPTIME
   else
     let COUNT=$TRIES+1
   fi
  done
done
