#!/bin/bash
# Limulus Slurm Suspend
# Copyright (c) Limulus Computing, Basement Supercomputing 2020
# TRIES is the number of times to try to suspend (power off) a node (or list).
# If node-poweroff returns quickly because it could not get the lock 
# (i.e. another node is starting/stopping).  
#
# Note: if node-poweroff gets the lock, it does not return until it
# confirmes the node is not responding. If it does not get a lock (another node 
# starting or stopping) then it waits for a randmom number of seconds between 20 and 180.
# test for needed utilities
if [ ! -f /usr/sbin/node-poweroff ]; then
  logger "Resume ERROR: Missing /usr/sbin/node-poweroff. Exiting"
  exit 1
fi
if [ ! -f /etc/warewulf/.Limulus/slurm-node-up.sh ]; then
  logger "Resume ERROR: Missing /etc/warewulf/.Limulus/slurm-node-up.sh. Exiting"
  exit 1
fi

TRIES=5
logger "Slurm Suspend ($0) for node(s) $1"
hosts=`scontrol show hostnames $1`
for host in $hosts
do
 COUNT=1
 SLEEPTIME=30
 while [ "$COUNT" -le "$TRIES" ];do
   logger "Suspend: node-poweroff -s $host"
   #echo " ----- `date` NODE: $host -----" >> /tmp/slurmsuspend
   sudo /usr/sbin/node-poweroff  -s $host 
   RESULT=`sudo /etc/warewulf/.Limulus/slurm-node-up.sh $host`
   logger "Suspend: $host is up? $RESULT"
   if [ "$RESULT" == "YES" ]; then
     let COUNT=$COUNT+1
     SLEEPTIME=`shuf -i20-180 -n1`
     logger "Suspend: $host will retry shut-down in $SLEEPTIME seconds"
     sleep $SLEEPTIME
   else
     let COUNT=$TRIES+1
   fi
  done
done

