#!/bin/sh
# this script reads the temps for Intel Core and AMD Ryzen using lm_sensors 
# and send it to the ganglia using gmetric
# Based on the original from: http://computational.engineering.or.id/LM_Sensors#Integrasi_Dengan_Ganglia
# assumes that the lines reported by lm_sensors are formatted like this for Intel Core processors
#   Core 0: +48.0B0C (high = +90.0B0C, crit = +100.0B0C)
# There is one for each core.
# For AMD Ryzen there is single temp
#   Tdie:         +31.2B0C  (high = +70.0B0C)
# If no appropriate module is found the temperature is returned as 0.0
# Credit: https://gist.github.com/1387192
# Ryzen Update: December 6, 2019, deadline@basement-supercomputing.com
# Modified August 28, 2020 to just return temperature as text if any argument given.
# This feature will be used by an updated (Limulus specific)  wulfd that
# now includes temperature
# Any errors from the sensor command are sent to /dev/null. This happens
# when a module (almost never the CPU, more like the nvme or video) throws and error. 
# to see any erros, just run "sensors" outside of this script.
SENSORS="/usr/bin/sensors"
GMETRIC=/usr/bin/gmetric
#set -x
if [ -x $GMETRIC ] || [ $# != 0 ] ; then
  let count=0
  sum=0.0
  temp=0.0
  MODULE=$($SENSORS 2>/dev/null|grep coretemp-isa-0000|gawk '{print $1}')
  if [ "$MODULE" = "coretemp-isa-0000" ]; then
    for temp in $($SENSORS 2>/dev/null | grep "^Core" |gawk '{print $3}'|sed 's/+//'| sed 's/\xc2\xb0C//'); do
    sum=$(echo $sum+$temp | bc)
    # echo $temp, $sum
    let count+=1
    done
    temp=$(echo "$sum/$count" | bc)
  else
    MODULE=$($SENSORS 2>/dev/null|grep k10temp-pci-00c3|gawk '{print $1}')
    if [ "$MODULE" = "k10temp-pci-00c3" ]; then
      temp=$($SENSORS 2>/dev/null|grep "Tdie"|gawk '{print $2}'|sed 's/+//'|sed 's/\xc2\xb0C//')
    else
      temp=0.0
   fi
  fi
  if [ $# == 0 ]; then
    $GMETRIC -t float -n "cpu_temp" -u "Celsius" -v $temp
  else
    echo $temp 
  fi 
fi

